<div align="Center">

# frizzle 

Combine spectra by forward modeling.

[![Test Status](https://github.com/andycasey/frizzle/actions/workflows/ci.yml/badge.svg)](https://github.com/andycasey/frizzle/actions/workflows/ci.yml)
[![Coverage Status](https://coveralls.io/repos/github/andycasey/frizzle/badge.svg?branch=main&service=github)](https://coveralls.io/github/andycasey/frizzle?branch=main)

</div>

# Install

```
uv add frizzle
```

## Authors:
- **David W Hogg** (NYU) (MPIA) (Flatiron)
- **Andy Casey** (Monash) (Flatiron)

## License:
Copyright 2022-2025 the authors.
All code herein is licensed for reuse under the open-source *MIT License*.
See the file `LICENSE` for more details.

## Contributors / Acknowledgements:
- **Matt Daunt** (NYU)
- **Adrian Price-Whelan** (Flatiron)
- **Thomas Hilder** (Monash)
- The **Astronomical Data Group** at the Flatiron Institute, and the **Inference Group** at Monash University.
